@@ -1319,7 +1319,7 @@ sortlength(THD *thd, SORT_FIELD *sortorder, uint s_length,
 	length++;				// Place for NULL marker
 #ifdef ENABLE_SENNA
       if (my_thread_var->sen_flags & SENNA_USE_2IND)
-	my_thread_var->sen_flags |= SENNA_FILESORT;
+	DEBUG_2IND(my_thread_var->sen_flags |= SENNA_FILESORT);
 #endif /* ENABLE_SENNA */
     }
     else
