@@ -2453,7 +2453,7 @@ bool Item_sum_count_distinct::setup(THD *thd)
   /* Create a table with an unique key over all parameters */
 #ifdef ENABLE_SENNA
   if (my_thread_var->sen_flags & SENNA_USE_2IND)
-    my_thread_var->sen_flags |= SENNA_DISTINCT;
+    DEBUG_2IND(my_thread_var->sen_flags |= SENNA_DISTINCT);
 #endif /* ENABLE_SENNA */
   for (uint i=0; i < arg_count ; i++)
   {
